@@ -3,10 +3,7 @@ import asyncio
 from blinker.base import Signal
 
 
-try:
-    schedule = asyncio.ensure_future
-except AttributeError:
-    schedule = asyncio.async
+schedule = asyncio.ensure_future
 
 
 @asyncio.coroutine
@@ -18,7 +15,8 @@ def _wrap_plain_value(value):
 
 
 def send_async(self, *sender, **kwargs):
-    return [(receiver, schedule(_wrap_plain_value(value)))
+    loop = kwargs.get('_loop')
+    return [(receiver, schedule(_wrap_plain_value(value), loop=loop))
             for receiver, value
             in self.send(*sender, **kwargs)]
 
